https://bugzilla.mozilla.org/show_bug.cgi?id=1391072

Patch included to build both 32 and 64-bits on sparc

--- a/build/autoconf/config.guess	2020-02-12 20:59:07.612715690 -0800
+++ b/build/autoconf/config.guess	2020-02-12 21:03:59.602960430 -0800
@@ -373,7 +373,20 @@
 	echo sparc-hal-solaris2`echo ${UNAME_RELEASE}|sed -e 's/[^.]*//'`
 	exit ;;
     sun4*:SunOS:5.*:* | tadpole*:SunOS:5.*:*)
-	echo sparc-sun-solaris2`echo ${UNAME_RELEASE}|sed -e 's/[^.]*//'`
+        eval $set_cc_for_build
+        SUN_ARCH=sparc
+        # If there is a compiler, see if it is configured for 64-bit objects.
+        # Note that the Sun cc does not turn __LP64__ into 1 like gcc does.
+        # This test works for both compilers.
+        if [ "$CC_FOR_BUILD" != no_compiler_found ]; then
+            if (echo '#ifdef __sparcv9'; echo IS_64BIT_ARCH; echo '#endif') | \
+                (CCOPTS= $CC_FOR_BUILD -E - 2>/dev/null) | \
+                grep IS_64BIT_ARCH >/dev/null
+            then
+                SUN_ARCH=sparc64
+            fi
+        fi
+	echo ${SUN_ARCH}-sun-solaris2`echo ${UNAME_RELEASE}|sed -e 's/[^.]*//'`
 	exit ;;
     i86pc:AuroraUX:5.*:* | i86xen:AuroraUX:5.*:*)
 	echo i386-pc-auroraux${UNAME_RELEASE}
